def budget(money):
    beer = money // 2
    bottle, top = beer, beer
    print("Can buy : ", beer)
    while True:
        a, b = bottle // 2, top // 4
        tmp = a + b
        if tmp >= 0:
            beer += a + b
            bottle = a + b + bottle % 2
            top = a + b + top % 4
            print("Beer={}, Bottle ={}, Top={}".format(beer, bottle, top))
            if not bottle // 2 + top // 4:
                break
    return print("Final drink = {}".format(beer))



from distutils.core import setup

setup(
    name='beer_beer',
    version='1.0.0',
    author='Terry Wong',
    author_email='terrywpl@gmail.com',
    url='http://google.com',
    description='calculate how many beer can buy',
    py_modules=['Beer'],
)